# chemcat
> Chemistry Calculator for Atmospheres

[![Tests](https://github.com/AtmoLib/chemcat/actions/workflows/python-package.yml/badge.svg)](https://github.com/AtmoLib/chemcat/actions/workflows/python-package.yml?query=branch%3Amain)
[![Documentation Status](https://readthedocs.org/projects/chemcat/badge/?version=latest)](https://chemcat.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/chemcat.svg)](https://pypi.org/project/chemcat)
[![Conda Version](https://img.shields.io/conda/vn/conda-forge/chemcat.svg)](https://anaconda.org/conda-forge/chemcat)
[![GitHub](https://img.shields.io/github/license/atmolib/chemcat.svg?color=blue)](https://chemcat.readthedocs.io/en/latest/license.html)


### Install as:
```
pip install chemcat
```
or:
```
conda install -c conda-forge chemcat
```


### Docs at:
<https://chemcat.readthedocs.io/en/latest/>

### Cite as:
```bibtex
@ARTICLE{CubillosBlecicEtal2022journalRadiativeChemicalEquilibrium,
       author = {{Cubillos}, Patricio and {Blecic}, Jasmina and {Fossati}, Luca},
        title = "{Radiative and Chemical Equilibrium Calculations with Application to Exoplanets}",
      journal = {journal},
         year = 2022,
       adsurl = {https://ui.adsabs.harvard.edu/abs/2022journ.000....0C},
      adsnote = {Provided by the SAO/NASA Astrophysics Data System}
}
```
